@@ -1037,7 +1037,7 @@ class Main(cmd.Cmd):
         self.default(self.bot.get_message(self.bot.last_response))
 
     @busy_bar.run()
-    def default(self, line, exit_on_error: bool = False):
+    def default(self, line, exit_on_error: bool = False, normal_stdout: bool = False):
         """Chat with LLM"""
         if not bool(line):
             return
@@ -1071,6 +1071,20 @@ class Main(cmd.Cmd):
                 busy_bar.start_spinning()
                 generated_response = generate_response()
 
+                if normal_stdout or not self.prettify and not self.disable_stream:
+                    # Resolves : https://github.com/Simatwa/python-tgpt/issues/42 & 43
+                    cached_response: str = ""
+                    if not normal_stdout:
+                        busy_bar.stop_spinning()
+                    for response in generated_response:
+                        offset = len(cached_response)
+                        print(response[offset:], end="")
+                        cached_response = response
+                    if not normal_stdout:
+                        # Interactive prompt
+                        print("")
+                    return
+
                 if self.quiet:
                     busy_bar.stop_spinning()
                     console_ = Console()
@@ -1760,7 +1774,7 @@ class ChatGenerate:
         bot.prettify = prettify
         bot.vertical_overflow = vertical_overflow
         bot.disable_stream = whole
-        bot.default(prompt, True)
+        bot.default(prompt, True, normal_stdout=(sys.stdout.isatty() == False))
 
 
 class Awesome:
@@ -2385,6 +2399,34 @@ class API:
 
         uvicorn.run(app, host=bind, port=port, log_level=log_level)
 
+    @staticmethod
+    @click.command(context_settings=this.context_settings)
+    @click.argument("content", required=True, type=click.Choice(["images", "all"]))
+    @click.option("-y", "--yes", is_flag=True, help="Okay to all confirmation prompts")
+    @click.help_option("-h", "--help")
+    def clear(content: str, yes: bool):
+        """Delete api's static contents"""
+        from pytgpt.utils import api_static_image_dir, api_static_dir
+        from pathlib import Path
+        import shutil
+
+        static_contents_map: dict[str, Path] = {
+            "images": api_static_image_dir,
+            "all": api_static_dir,
+        }
+        content_path: Path = static_contents_map[content]
+        if not yes:
+            yess: bool = click.confirm(
+                f"Are you sure to clear {content} '{content_path.as_posix()}'"
+            )
+            if not yess:
+                return
+        else:
+            pass
+        total_entries = len(os.listdir(content_path))
+        shutil.rmtree(content_path)
+        click.secho(f"{content.title()} cleared ({total_entries})", fg="yellow")
+
 
 def make_commands():
     """Make pytgpt chained commands"""
@@ -2421,6 +2463,7 @@ def make_commands():
 
     # FastAPI
     EntryGroup.api.add_command(API.run)
+    EntryGroup.api.add_command(API.clear)
 
 
 # @this.handle_exception
